import React, { useState } from 'react';

import articles from './articles.csv';

function filterArticles(articles, query, category) {
  let filteredArticles;
  if (query === '') {
    filteredArticles = [...articles];
  } else {
    filteredArticles = articles.filter(article => {
      if (article.title != null && article.title.includes(query)) {
        return true;
      }
      if (article.title2 != null && article.title2.includes(query)) {
        return true;
      }
      return false;
    });
  }

  filteredArticles = filteredArticles.filter(article => {
    if (category === 'all') {
      return true;
    }
    return article[category] === 1;
  });

  return filteredArticles;
}

const Icon = ({it, environment, social}) => {
  return (
    <React.Fragment>
      {it === 1 && <span className={'icon it'}>IT</span>}
      {environment === 1 && <span className={'icon environment'}>環境</span>}
      {social === 1 && <span className={'icon social'}>社会・科学</span>}
    </React.Fragment>
  );
};

const App = () => {
  const [ query, setQuery ] = useState('');
  const [ category, setCategory ] = useState('all');

  const categories = [
    {key: 'all', label: 'すべて'},
    {key: 'it', label: 'IT'},
    {key: 'environment', label: '環境・エネルギー'},
    {key: 'social', label: '社会・経済・科学'},
  ];

  const filteredArticles = filterArticles(articles, query, category);

  return (
    <div>
      <div style={{marginBottom: '1rem'}}>
        <input type="text" style={{width: '250px'}} placeholder="検索" value={query} onChange={e => setQuery(e.target.value)}/>
        <div>
          分野：
          {categories.map(({key, label}) => (
            <React.Fragment key={key}>
              <input type="radio" checked={category === key} onChange={e => e.target.checked && setCategory(key)} />
              <span style={{cursor: 'default', marginRight: '10px'}} onClick={() => setCategory(key)}>{label}</span>
            </React.Fragment>
          ))}
        </div>
      </div>

      <h2>コラム一覧</h2>
      <table className={'table'}>
        <tbody>
          {filteredArticles.map(article => {
            return (
              <tr key={article.date + article.title}>
                <td className={'date'}>
                  {article.date}
                </td>
                <td className={'title'}>
                  <div>
                    <Icon it={article.it} environment={article.environment} social={article.social} />
                  </div>
                  <div>
                    <div>
                      <a href={`https://www.mizuho-ir.co.jp${article.path}`}>{article.title}</a>
                    </div>
                    <div>
                      {article.title2}
                    </div>
                  </div>
                </td>
              </tr>
            );
          })}
        </tbody>
      </table>
    </div>
  );
};

export default App;
